# air_quality_index_schaefer {#aqi-schaefer}
This method provides a single indicator (called the Air Quality Index (AQI)) for the assessment of air quality. The AQI can take values between 0 and 1, with 1 indicating that the allowable limits defined by ICAO are reached by all species. Therefore, low values are preferable.

## General principles {#aqi-schaefer-generalprinciples}
The calculation method, including all required inputs, is described in Schaefer (2017) \cite Sch17. It is:

\f$ AQI = 1/n \cdot \sum x_i/x_{i,max}\f$

where:

- \f$ x_i \f$: emission mass [g] ( for CO, HC, NOx) or maximum concentration [mg/m^3] ( for soot) during the landing and takeoff cycle,
- \f$ x_{i,max}\f$: regulatory value defined by ICAO, the ratio of emission mass Dp [g] emitted during LTO and the rated thrust F00 [kN],
- \f$ n \f$: number of emission species.

## Input-Data {#aqi-schaefer-input}
Only engine and emission data are needed. To construct the engine object, the following is required from acXML:
```xml
<engine description="Description of engine">
    <engine_model description="Name of selected engine model">
        <value>V2527-A5</value>
    </engine_model>
    <scale_factor description="Scale factor">
        <value>1.168175939</value>
        <unit>1</unit>
        <lower_boundary>0</lower_boundary>
        <upper_boundary>5</upper_boundary>
    </scale_factor>
</engine>
```

From `ecological_assessment_results` following parameter will be read:
```xml
<calculation_results description="Results of calculation method">
    <mission_emissions description="Results of mission emission calculation">
        <study_mission description="Results of study mission calculation">
            <emissions description="Emissions of study mission">
                <LTO_cycle description="Emissions of landing and takeoff cycle">
                    <HC description="LTO HC emissions of one study mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </HC>
                    <CO description="LTO CO emissions of one study mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO>
                    <NOx description="LTO NOx emissions of one study mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </NOx>
                    <c_soot_LTO_max description="Maximum soot concentration during study mission LTO">
                        <value>0</value>
                        <unit>1</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </c_soot_LTO_max>
                </LTO_cycle>
            </emissions>
        </study_mission>
    </mission_emissions>
</calculation_results>
```
## Output-Data {#aqi-schaefer-output}
The submodule writes its calculation results into the HTML report located in `aircraft_exchange_file_directory/reporting/reportHTML`.