/**
 * \file empennageDesign.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief base module for empennage design
 * \version 0.1
 * \date 2023-10-11
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "empennageDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>
#include <format>

#include "bwb/vertical_tails/low/LowVerticalTailsBwb.h"
#include "taw/conventional/low/lowConventionalEmpennageDesign.h"

EmpennageDesign::EmpennageDesign(const int argc, char *argv[], const std::string &toolName,
                                 const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string usedtype = EndnodeReadOnly<std::string>("requirements_and_specifications/design_specification/configuration/empennage_definition/empennage_type").read(rtIO_->acxml).value();
  std::string fidelity = EndnodeReadOnly<std::string>("program_settings/fidelity_selection").read(rtIO_->moduleConfig).value();

  /* Register existing strategies */
  /* tube and wing strategies */
  strategy.registerStrategy<taw::low::Conventional>({"tube_and_wing", "conventional", "low"});

  /* blended wing body strategies*/
  strategy.registerStrategy<bwb::low::VerticalTails>({"blended_wing_body", "vertical_tails", "low"});

  /* Set desired strategy */
  strategy.setStrategy({configuration, usedtype, fidelity}, rtIO_);
}
