# Import own modules.
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.cabinwidthcalculation import cabin_width_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.cabinlengthcalculation import cabin_length_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.payloadtubewatervolumecalculation import payload_tube_water_volume_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.payloadtubewidthcalculation import payload_tube_width_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.payloadtubewallthicknesscalculation import payload_tube_wall_thickness_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.payloadtubefloorthicknesscalculation import payload_tube_floor_thickness_calculation  # noPep8 e501
from src.blended_wing_body.empirical.blended_wing_body_design_tu_berlin.general.call_functions.tube_geometry.payloadtubereferencepointcalculation import payload_tube_reference_point_calculation  # noPep8 e501


def generate_tubes(dict_ac_exchange, dict_mod_config, payload_tube_description, runtime_output):
    """ Generates main geometry parameter of the blended wing body passenger tubes.

    :param dict dict_ac_exchange: Dict containing parameter and according values from aircraft exchange file
    :param dict dict_mod_config: Dict containing parameter and according values from module configuration file
    :param dict payload_tube_description: Dict containing parameter and values of current blended wing body design
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict payload_tube_description: Dict containing parameter and values of current payload tube design
    """

    # Function call to calculate the passenger cabin width in [inch].
    payload_tube_description['passenger_cabin_width'], payload_tube_description['interior_description'] = \
        cabin_width_calculation(dict_ac_exchange, dict_mod_config, runtime_output)

    # Function call to calculate the passenger cabin wall thickness in [inch].
    payload_tube_description['payload_tube_wall_thickness'] = \
        payload_tube_wall_thickness_calculation(dict_ac_exchange, payload_tube_description['passenger_cabin_width'],
                                                runtime_output)

    # Function call to estimate the payload tube width including structural parts in [inch].
    payload_tube_description['payload_tube_width'], payload_tube_description['total_width_of_passenger_compartments'] =\
        payload_tube_width_calculation(dict_ac_exchange, payload_tube_description['passenger_cabin_width'],
                                       payload_tube_description['payload_tube_wall_thickness'], runtime_output)

    # Function call to calculate the payload tube floor thickness in [inch].
    payload_tube_description['payload_tube_floor_thickness'] = \
        payload_tube_floor_thickness_calculation(payload_tube_description['payload_tube_wall_thickness'],
                                                 runtime_output)

    # Function call to calculate the total required passenger cabin area in [inch*inch].
    payload_tube_description['required_cabin_length_per_tube'], payload_tube_description['interior_description'] = \
        cabin_length_calculation(dict_ac_exchange, dict_mod_config, payload_tube_description, runtime_output)

    # function call to estimate the reference points in x-, y- and z-direction of each tube in [inch]
    payload_tube_description['payload_tube_center_reference_points'], \
        payload_tube_description['payload_tube_wall_reference_points'], \
        payload_tube_description['payload_tube_length'] = \
        payload_tube_reference_point_calculation(dict_ac_exchange, dict_mod_config, payload_tube_description,
                                                 runtime_output)

    # function call to estimate the passenger deck water volume in [inch*inch*inch]
    payload_tube_description['passenger_deck_volume'], payload_tube_description['cargo_deck_volume'], \
        payload_tube_description['passenger_deck_height'], payload_tube_description['cargo_deck_height'] = \
        payload_tube_water_volume_calculation(dict_ac_exchange, dict_mod_config, payload_tube_description,
                                              runtime_output)

    payload_tube_description['geometry_flag'] = True

    ''' debug print '''
    runtime_output.debug('Debug: The generate_tubes function was successfully executed!')

    return payload_tube_description
