/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_OPTIMIZEMISSIONPROFILE_LOW_FIDELITY_OPTIMIZEMISSIONPROFILE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_OPTIMIZEMISSIONPROFILE_LOW_FIDELITY_OPTIMIZEMISSIONPROFILE_H_

// #include <standardFiles/functions.h>
// #include <aixml/node.h>

#include <vector>
#include <string>
#include <memory>

#include "../../aircraft.h"
#include "../../fuelPlanning/abstractFuelPlanning.h"
#include "../abstractOptimizeMissionProfile.h"

// class aircraft;
// class fuelPlanning;

using std::vector;
using std::string;

namespace low {

/**\brief optimizeMissionProfile Global class containing the initial and the optimized mission
*
*/
class optimizeMissionProfile : public abstractOptimizeMissionProfile {
 public:
    /**\brief Constructor optimizeMissionProfile
    *\param theAircraft Address to the aircraft object
    */
    explicit optimizeMissionProfile(aircraft *theAircraft);

    /**\class theCruiseSteps Class containing flight data for each mission segment
    *
    */
    class theCruiseSteps {
     public:
        int ID; /**< Mission segment ID */
        double grossMass; /**< Aircraft mass (kg) */
        double oldFL; /**< Previous flight level (-) */
        double newFL; /**< Optimized flight level for the i flight segment (-) */
        double Mach; /**< Mach number (-) */

        theCruiseSteps() {
            ID = 0;
            grossMass = 0.;
            oldFL       = 0.;
            newFL       = 0.;
            Mach        = 0.;
        }
    };
    vector<theCruiseSteps> cruiseSteps; /**< List of the cruise steps */

    /**\brief Calculation of the optimized flight data
    *\param myFuelPlanning object of the fuelPlanning class
    *\param ioFile Aircraft file name
    *\param sizingForMTOM Switch if Design or Study mission shall be changed
    */
    void doOptimizeMission(std::shared_ptr<abstractFuelPlanning>& myFuelPlanning, const std::shared_ptr<RuntimeIO>& rtIO, bool sizingForMTOM) override;

    /**\brief Destructor optimizeMissionProfile
    *
    */
    virtual ~optimizeMissionProfile();

 private:
    aircraft *theAcftPt; /**< Pointer to the aircraft object */

    /**\brief Function to calculate the optimized flight level
    *\param theLift Lift at the mission segment (N)
    *\param theMach Mach number at the mission segment (-)
    *\return The optimized flight level (-)
    */
    double getNewFlightLevel(double theLift, double theMach);
};
}  // namespace low

#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_OPTIMIZEMISSIONPROFILE_LOW_FIDELITY_OPTIMIZEMISSIONPROFILE_H_

