/*  Copyright (C) 2023 Chair of Aircraft Design, Technical University Munich
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file energy_carrier.h
 * @author Sebastian Oberschwendtner (sebastian.oberschwendtner@tum.de)
 * @brief Defines the fuel types.
 * @version 3.0.0
 * @date 2023-12-14
 */

#ifndef SRC_ENERGY_CARRIER_H_
#define SRC_ENERGY_CARRIER_H_

/* === Includes === */
#include <unordered_map>

/* === Types === */
/**
 * @brief Enumerates the different available energy carriers.
 */
enum class EnergyCarrier
{
    Kerosene,       /**< Kerosene (Jet A-1) */
    Liquid_Hydrogen /**< Hydrogen */
};

/* === Type Aliases === */
/**
 * @brief Alias for energy carriers map.
 */
using EnergyCarriersMap = std::unordered_map<int, EnergyCarrier>;

#endif // SRC_ENERGY_CARRIER_H_
