/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "TransmissionShaft.h"

#include <cmath>

#include <runtimeInfo/runtimeInfo.h>

TransmissionShaft::TransmissionShaft(const std::string& Type)
    :
    Mass(0.0) {
    // NOTE (aigner#1#): efficiencyFactors from [Cha10] p.55 2010, composed of gearboxes, value is actually only valid for A320 Layout (cf. [Cha10] p. 54)
    if (Type == "Slat") {
        efficiencyFactor = 0.7850;
        rotationSpeedShaft = 1080 * 1 / 60; //in Sekunde
    } else if (Type == "Fowler") {
        efficiencyFactor = 0.8679;
        rotationSpeedShaft = 1080 * 1 / 60; //in Sekunde
    } else {
        myRuntimeInfo->err << "The system type \"" << Type << "\" is unknown. transmission shaft cannot be created!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
    //ctor
}

TransmissionShaft::~TransmissionShaft() {
    //dtor
}

void TransmissionShaft::getMass(const std::string& deviceType, double wingSpan) {
    // NOTE (aigner#1#): methods changed by Lammering in SV rev2131 March 2013
    if (deviceType == "Slat") {
        Mass = 16.661 * pow(2.71828, (0.0247 * wingSpan));
    } else if (deviceType == "Fowler") {
        Mass = 0.833 * 16.661 * pow(2.71828, (0.0247 * wingSpan));
    } else {
        myRuntimeInfo->err << "The system type \"" << deviceType << "\" is unknown. transmission shaft mass cannot be calculated!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
}
