# Design your first wing {#design-your-first-wing}
Let's dive into the fun part. In this guide we will create a wing for a classic tube and wing configuration with a cantilever wing design method.

  - [Requirements:](#requirements) - Information on tool requirements
  - [Design parameters:](#design-parameters) - Information on design parameters
  - [Tool execution:](#tool-execution) - Tool execution information
  - [Reporting](#reporting) - Wing Design tool report information
  - [Changing parameters](#changing-parameters) - The fun part! Let's change parameters
  - [Troubleshooting](#troubleshooting) - Something went wrong? Maybe you are not the first one!

The wing will be part of a generic tube and wing aircraft which is a look-a-like A320.

## Requirements
Therefor we use an _Aircraft Exchange File_ where the tools _initial\_sizing_ and _fuselage\_design_ already run.

From the _Aircraft Exchange File_ we have the following information:

From the Requirements block:
Parameter                  |         Value
:--------------------------|-------------:
A/C Type                   |         CeraS
A/C Model                  |      SMR-2020
Configuration Type         | Tube and Wing
Wing definition            |           low
ICAO Aerodrome Ref Code    |        3CIIIB
Initial cruise mach number |          0.78

From _initial\_sizing_ tool

Parameter    |           Value
:------------|---------------:
MTOM         |        64232 kg
Wing loading | 619.8444 kg/m^2

> [!NOTE]
> Parameters of the fuselage are not listed - however, it has a length of ~37m and a width of ~4m
## Design parameters
Wing Design tool parameters for cantilever method

Parameter | Value (parameter in order of occurence)
:-- | --:
`wing_area` | `mode_1` &rarr; `by_loading_and_mtom`
`sweep` | `mode_0` &rarr; `user_defined (27°)`
`taper_ratio` | `mode_0` &rarr; `user_defined (0.17)`
`dihedral` | `mode_1` &rarr; `by_wing_position_and_quarter_chord_sweep (raymer)`,
`aspect_ratio` | `mode_0` &rarr; `user_defined (10.3)`
`relative_kink_position` | `mode_0` &rarr; `user_defined (0.3, 10°)`
`wing_profile_and_thickness` | `mode_1` &rarr; `torenbeek-jenkinson (F15, 0.15, 1.12)`
`mass` | `mode_0` &rarr; `flops (0.0,0.0,0.5)`
`control_devices` | `mode_1` &rarr; `empirical (slat, flap_fowler)`
`spars` | `mode_0` &rarr; `user_defined ((front_spar,0.0,0.2,0.2, 1.0,0.2,0.2),(rear_spar,0.0,0.6,0.6,1.0,0.6,0.6) `


## Tool execution
The tool can be executed from console directly if all paths are set (see [How to run a tool](howToRunATool.md)).

We go through the tool output step by step
```
*******************************************************************************
18.11.2024 21:50:22 - Start wingDesign
18.11.2024 21:50:22 - [MODULE RUNTIMEINFO] - wingDesign
18.11.2024 21:50:22 -    [CONSOLE  ] - [ON]
18.11.2024 21:50:22 -    [LOG      ] - [ON]
18.11.2024 21:50:22 -    [PLOT     ] - [ON]
18.11.2024 21:50:22 -       [COPY  ] - [ON]
18.11.2024 21:50:22 -       [DELETE] - [ON]
18.11.2024 21:50:22 -    [REPORT   ] - [ON]
18.11.2024 21:50:22 -    [TEX      ] - [OFF]
18.11.2024 21:50:22 -    [INFOFILES] - [OFF]
18.11.2024 21:50:22 -    [GNUPLOT]
18.11.2024 21:50:22 -       [PATH    ] -
18.11.2024 21:50:22 -       [FILENAME] - DEFAULT
18.11.2024 21:50:22 -    [INKSCAPE]
18.11.2024 21:50:22 -       [PATH    ] -
18.11.2024 21:50:22 -       [FILENAME] - DEFAULT
18.11.2024 21:50:22 -    [LOGFILE]
18.11.2024 21:50:22 -       [PATH    ] - .
18.11.2024 21:50:22 -       [FILENAME] - wingDesign.log
18.11.2024 21:50:22 -    [IO/ACXML]
18.11.2024 21:50:22 -       [PATH    ] - ../projects/CSR/CSR-02
18.11.2024 21:50:22 -       [FILENAME] - csmr-2020.xml
18.11.2024 21:50:22 -    [MODCONFIG]
18.11.2024 21:50:22 -       [PATH    ] - .
18.11.2024 21:50:22 -       [FILENAME] - wingDesign_conf.xml
18.11.2024 21:50:22 - Checking directory... [REPORT]
18.11.2024 21:50:22 - Checking directory... [TEX]
18.11.2024 21:50:22 - Checking directory... [HTML]
18.11.2024 21:50:22 - Checking directory... [PLOT]
18.11.2024 21:50:22 - Checking directory... [CSVFILES]
18.11.2024 21:50:22 - Checking directory... [CSVFILESTOOL]
18.11.2024 21:50:22 - Creating directory... [CSVFILESTOOL]
18.11.2024 21:50:22 - Checking directory... [PLOTFILES]
18.11.2024 21:50:22 - Checking directory... [PLOTFILESTOOL]
18.11.2024 21:50:22 - Creating directory... [PLOTFILESTOOL]
18.11.2024 21:50:22 - Checking directory... [LOGFILES]
```
To this point, the module is in the top level stage and creates folders and checks the configuration file settings from the control block. Here you can see some common information.

Afterwards the module progresses and starts with the wing design initialization where it checks the airfoildata directory
```
18.11.2024 21:50:22 - Initializing wing design ... [START]
18.11.2024 21:50:22 - Checking directory... [AIRFOILDATA]
18.11.2024 21:50:22 - Initializing wing design ... [FINISHED]
```
Nothing fancy to this point! Now, we go to the interesting part - the design part begins with the check of the kink. Afterwards it gives you information on your parameter settings and gives you some more information about some selections like the ICAO Aerodrome reference code.
```
18.11.2024 21:50:22 - Run wing design ... [START]
18.11.2024 21:50:22 - Selected design method ... [START]
18.11.2024 21:50:22 - Wing Design ... [Start]
18.11.2024 21:50:22 - Wing kink check ...
18.11.2024 21:50:22 - Wing is kinked  ... [TRUE]
Quarter chord sweep [method]: user_defined
Quarter chord sweep  [value]: 27 [deg]
Wing area [method]: by_loading_and_mtom
Wing area  [value]: 104.198 [m^2]
18.11.2024 21:50:22 - ICAO EASA Aerodrome reference code: 3CIIIB
	Limts for  : ICAO field length
	Code       : 3
	Lower limit: 1200
	Upper limit: 1800
	Limts for  : ICAO wing span
	Code       : C
	Lower limit: 24
	Upper limit: 36
	Limts for  : FAA ADG tail height
	Code       : III
	Lower limit: 9.144
	Upper limit: 13.716
	Limts for  : ICAO aircraft approach speed
	Code       : B
	Lower limit: 169
	Upper limit: 224
Wing aspect ratio [method]: user_defined
Wing aspect ratio  [value]: 10.3 [1]
Wing taper ratio [method]: user_defined
Wing taper ratio  [value]: 0.17 [1]
Dihedral [method]: raymer
Dihedral  [value]: 5 [deg]
Maximum inner trailing edge sweep [method]: user_defined
Maximum inner trailing edge sweep  [value]: 3 [deg]
Relative kink position [method]: user_defined
Relative kink position  [value]: 0.3 [1]
```
The aspect ratio with 10.3 is within limits of the 3CIIIB, otherwise a warning would have occured!

In the next part, the tool computes the thickness distribution according to the selected method and goes further to the control and spars definition. After finishing this, the masses and the center of gravity as well as the wing position alongside the fuselage is calculated.
```
Wing profile and thickness [method]: torenbeek_jenkinson
Wing profile and thickness [values]:
	Eta               : 0
	Thickness to chord: 0.15
	Profile           : F15
	Eta               : 0.121122
	Thickness to chord: 0.15
	Profile           : F15
	Eta               : 0.3
	Thickness to chord: 0.13803
	Profile           : F15
	Eta               : 1
	Thickness to chord: 0.0911906
	Profile           : F15
Leading edge check ... [OK]
Trailing edge check ... [OK]
Spars [method]: user_defined
Spars [values]:
	Number 2 [1]
Wing kink check ...
18.11.2024 21:50:22 - Wing is kinked  ... [TRUE]
Relative kink position [method]: user_defined
Relative kink position  [value]: 0.3 [1]
18.11.2024 21:50:22 - Wing kink check ...
18.11.2024 21:50:22 - Wing is kinked  ... [TRUE]
Control devices [method]: empirical
Control devices [values]:
	Name              : slat
	Deflections       : 0	40
	Name              : slat
	Deflections       : 0	40
	Name              : flap_fowler
	Deflections       : 0	45
	Name              : flap_fowler
	Deflections       : 0	45
	Name              : aileron
	Deflections       : -20	20
	Name              : spoiler_ground
	Deflections       : 0	45
	Name              : spoiler_air
	Deflections       : 0	45
	Name              : spoiler_air
	Deflections       : 0	45
	Name              : spoiler_air
	Deflections       : 0	45
	Name              : spoiler_air
	Deflections       : 0	45
18.11.2024 21:50:22 - Selected design method ... [FINISHED]
18.11.2024 21:50:22 - Selected mass method   ... [START]
18.11.2024 21:50:22 - Wing mass estimation using ... FLOPS
18.11.2024 21:50:22 - Calculating ...
18.11.2024 21:50:22 - Calculated wing mass ... 5822.87[kg]
18.11.2024 21:50:22 - Wing bending material mass ... 3077.49[kg]
18.11.2024 21:50:22 - Wing shear material and control surface mass ... 2238.51[kg]
18.11.2024 21:50:22 - Wing miscellaneous items mass ... 506.872[kg]
18.11.2024 21:50:22 - Calculate Center of Gravity ...
18.11.2024 21:50:22 - CG Position...
18.11.2024 21:50:22 - x ... 16.9761
18.11.2024 21:50:22 - y ... 0
18.11.2024 21:50:22 - z ... -0.673262
18.11.2024 21:50:22 - Selected mass method   ... [FINISHED]
18.11.2024 21:50:22 - Run wing design ... [FINISHED]
```
Now the design has finished.

In the following the wing data will be written to the _Aircraft Exchange File_ (Update) and the report will be written.
```
18.11.2024 21:50:22 - Update designed wing ... [START]
18.11.2024 21:50:22 - Update designed wing ... [FINISHED]
18.11.2024 21:50:22 - Report designed wing ... [START]
18.11.2024 21:50:24 - CSS code written to style.css successfully.
18.11.2024 21:50:24 - Report designed wing ... [FINISHED]
```


Executing the tool with reporting on gives you a HTML report for the designed wing.
Let's have a look at it.
## Reporting
The HTML report is splitted - on the left half, one can see numerical information of the wing design. The right side contains plots and visual information.

![Report Page](content/figures/Report_page_wing_design.png)

It starts with general information followed by section parameters. Then you get information on spars and control devices. It concludes with mass information.

The plot side starts with a general wing planfrom view, followed by the airfoil shape and the thickness and twist distribution


## Changing parameters
The mass here seems quite low - this is due to the `fcomp` parameter in the `mass` block of the configuration file which is set to `0.5` (`fcomp` defines the part of composite utilization), so we want to decrease the composite part so we will set this to `fcomp = 0.2`.

The results are indeed different:
Now we have a wing mass of `6424kg` instead of `5822kg`.

Also we can try to trigger an error - lets increase the aspect ratio to get out of the ICAO Aerodrome reference code region (set `aspect_ratio = 18`).

Now we see the following during code exectuion:
```
Wing aspect ratio [method]: user_defined
Wing aspect ratio  [value]: 18 [1]
18.11.2024 22:15:26 - WARNING: Calculated aspect ratio > maximum_possible_aspect_ratio
18.11.2024 22:15:26 - WARNING: Switch to maximum possible aspect_ratio
Wing taper ratio [method]: user_defined
...
```
The tool adapted the wing aspect ratio to the maximum possible aspect ratio since the aspect ratio we defined was way too high.

Soo .... Now it is your turn!

<dl class="section invariant">
<dt>Tip</dt>
<dd>
Start by changing only one parameter at once. There might be interactions with other parameters, so don't rush!
</dd>
## Troubleshooting
- Tool does not run properly:
  - Make sure you have all the paths set up correctly and the specified elements exist!
- Tool is not there:
  - You can build the tool directly from scratch - see therefor [How to build a tool](howToBuildATool.md)

