/**
 * \file wingProfileMethods.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Wing profile and thickness distribution methods
 * \version 0.1
 * \date 2023-12-19
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_
#define WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_

#include <string>
#include <tuple>
#include <vector>
using modes = std::string;

namespace user_defined {
std::vector<std::tuple<double, double, std::string>> wing_profile_and_thickness_distribution(
    const std::vector<std::tuple<double, double, std::string>> user_wing_profiles_and_thickness_to_chord,
    const double eta_fuselage, std::vector<double> eta_positions);
}

namespace torenbeek_jenkinson {
std::vector<std::tuple<double, double, std::string>> wing_profile_and_thickness_distribution(
    const std::string& wing_profile, const double maximum_thickness_to_chord_ratio,
    const double technology_factor_airfoil, const double mach_design, const double design_altitude,
    const double quarter_chord_sweep, const double mach_drag_divergence, const double wing_loading,
    const double eta_fuselage, std::vector<double> eta_positions);
}  // namespace torenbeek_jenkinson

std::vector<std::tuple<double, double, std::string>> get_wing_profile_and_thickness(
    modes wing_profile_and_thickness,
    const std::vector<std::tuple<double, double, std::string>> user_wing_profile_and_thickess,
    const std::string& wing_profile, const double maximum_thickness_to_chord_ratio,
    const double technology_factor_airfoil, const double mach_design, const double design_altitude,
    const double quarter_chord_sweep, const double mach_drag_divergence, const double wing_loading,
    const double eta_fuselage, std::vector<double> eta_positions);

#endif  // WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_
