/**
 * \file bisection.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Bisection method
 * \version 0.1
 * \date 2023-11-03
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef BISECTION_METHOD_H_
#define BISECTION_METHOD_H_

#include <cmath>
#include <exception>
#include <functional>

double bisection_algorithm(const std::function<double(double)> &fun, double start_left, double start_right,
                           double end_condition);

double bisection_algorithm(const std::function<double(double)> &fun, double start_left, double start_right,
                           double end_condition = 1E-10) {
  double intermediate, left = start_left, right = start_right;
  constexpr int max_iteration = 400;
  int iteration = 0;
  double to_check = 0;
  double value_left, value_right;
  do {
    value_left = fun(left);
    value_right = fun(right);
    to_check = value_left * value_right;
    if (to_check < 0.0) {
      intermediate = 0.5 * (left + right);
      if (fun(left) * fun(intermediate) < 0) {
        right = intermediate;
      } else {
        left = intermediate;
      }
    } else {
      if (abs(value_left) < 1E-20) {
        return left;
      } else if (abs(value_right) < 1E-20) {
        return right;
      } else {
        throw("Bad condition for bisection method f(l)*f(r) >= 0 -> change bounds");
      }
    }
  } while ((abs(right - left) > 1E-20) && ((abs(value_left) > 1E-10) || (abs(value_right) > 1E-10)) &&
           (iteration < max_iteration));
  return right;
}

#endif  // BISECTION_METHOD_H_